# Cloudbeds PMS
<p>Welcome to the documentation for <strong>Cloudbeds API Version v2</strong>! If you are looking to learn how to use the Cloudbeds API to access guest information, reservations, or similar data for your Cloudbeds customers, then you've come to the right place.</p><p>In this document you will find all the API methods we provide along with explanations for parameters and response examples.</p><p>If you have questions about different implementation steps (e.g. how to implement OAuth 2.0), please refer to our <a href='https://integrations.cloudbeds.com/hc/en-us'>Integrations Portal</a>.</p><p>Be sure to <a href='https://go.pardot.com/l/308041/2018-07-24/qb2lg'>subscribe</a> to the monthly Cloudbeds API announcement mailing list to receive information on new additions and improvements to the Cloudbeds API and related developer tools.</p><p><strong>Endpoint:</strong> https://api.cloudbeds.com/{method}</p><p><strong>HTTPS:</strong> Our API requires HTTPS. We'll respond with an appropriate error if you're not using it.</p><p><strong>Request Format:</strong> HTTP GET, POST and PUT (Content-Type: application/x-www-form-urlencoded)</p><p><strong>Response Format:</strong> JSON</p><p><strong>Response Header:</strong> X-Request-ID is added to response headers in all calls to help accelerate support and troubleshooting.</p><p><strong><a href='https://integrations.cloudbeds.com/hc/en-us/articles/14104678058267-API-Documentation#postman-collection'><img src='https://run.pstmn.io/button.svg' alt='Run in Postman'></a></strong> use this link to access our Public collection in Postman.</p>

The `cloudbeds_pms` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v2
- Package version: 2.3.0
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with Cloudbeds PMS,
you can run the following:

```python

import cloudbeds_pms
from cloudbeds_pms.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.cloudbeds.com
# See configuration.py for a list of all supported configuration parameters.
configuration = cloudbeds_pms.Configuration(
    host = "https://api.cloudbeds.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with cloudbeds_pms.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = cloudbeds_pms.DoorlockKeysApi(api_client)
    door_lock_key_create_request_schema = cloudbeds_pms.DoorLockKeyCreateRequestSchema() # DoorLockKeyCreateRequestSchema | Key data

    try:
        # Create a new doorlock key.
        api_response = api_instance.door_lock_key_controller_create(door_lock_key_create_request_schema)
        print("The response of DoorlockKeysApi->door_lock_key_controller_create:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DoorlockKeysApi->door_lock_key_controller_create: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.cloudbeds.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DoorlockKeysApi* | [**door_lock_key_controller_create**](cloudbeds_pms/docs/DoorlockKeysApi.md#door_lock_key_controller_create) | **POST** /doorlock/v1/keys | Create a new doorlock key.
*DoorlockKeysApi* | [**door_lock_key_controller_delete**](cloudbeds_pms/docs/DoorlockKeysApi.md#door_lock_key_controller_delete) | **DELETE** /doorlock/v1/keys/{id} | Delete a doorlock key.
*DoorlockKeysApi* | [**door_lock_key_controller_index**](cloudbeds_pms/docs/DoorlockKeysApi.md#door_lock_key_controller_index) | **GET** /doorlock/v1/keys/{propertyId} | Get a list of doorlock keys for a specific app client and property.
*DoorlockKeysApi* | [**door_lock_key_controller_update**](cloudbeds_pms/docs/DoorlockKeysApi.md#door_lock_key_controller_update) | **PATCH** /doorlock/v1/keys/{id} | Update a doorlock key.
*DoorlockSettingsApi* | [**door_lock_settings_controller_delete**](cloudbeds_pms/docs/DoorlockSettingsApi.md#door_lock_settings_controller_delete) | **DELETE** /doorlock/v1/settings/{propertyId} | Delete doorlock settings for property for specific application client.
*DoorlockSettingsApi* | [**door_lock_settings_controller_single**](cloudbeds_pms/docs/DoorlockSettingsApi.md#door_lock_settings_controller_single) | **GET** /doorlock/v1/settings/{propertyId} | Get doorlock settings for property for specific application client.
*DoorlockSettingsApi* | [**door_lock_settings_controller_upsert**](cloudbeds_pms/docs/DoorlockSettingsApi.md#door_lock_settings_controller_upsert) | **PUT** /doorlock/v1/settings/{propertyId} | Upsert doorlock settings for property for specific application client.
*HousekeepingApi* | [**call_27abd48cb30106ec3251cf3baf34174c**](cloudbeds_pms/docs/HousekeepingApi.md#call_27abd48cb30106ec3251cf3baf34174c) | **GET** /housekeeping/v1/inspections/{propertyId} | Housekeeping inspection list
*ImportTasksApi* | [**import_task_controller_create**](cloudbeds_pms/docs/ImportTasksApi.md#import_task_controller_create) | **POST** /import/v1/tasks | Create a new import task and generate a temporary upload URL.
*ImportTasksApi* | [**import_task_controller_find_by_id**](cloudbeds_pms/docs/ImportTasksApi.md#import_task_controller_find_by_id) | **GET** /import/v1/tasks/{taskId} | Fetch import task by ID.
*ImportTasksApi* | [**import_task_controller_find_task_records**](cloudbeds_pms/docs/ImportTasksApi.md#import_task_controller_find_task_records) | **GET** /import/v1/tasks/{taskId}/records | Fetch import task records by ID.
*ImportTasksApi* | [**import_task_controller_get_all**](cloudbeds_pms/docs/ImportTasksApi.md#import_task_controller_get_all) | **GET** /import/v1/tasks | Fetch a list of previously uploaded imports.
*ImportTasksApi* | [**import_task_controller_reimport**](cloudbeds_pms/docs/ImportTasksApi.md#import_task_controller_reimport) | **POST** /import/v1/tasks/{taskId} | ReImport an import task and generate a temporary upload URL.


## Documentation For Models

 - [BadRequestErrorItemSchema](cloudbeds_pms/docs/BadRequestErrorItemSchema.md)
 - [BadRequestResponseSchema](cloudbeds_pms/docs/BadRequestResponseSchema.md)
 - [BadRequestResponseSchemaErrors](cloudbeds_pms/docs/BadRequestResponseSchemaErrors.md)
 - [BodyDynamicFilterSchema](cloudbeds_pms/docs/BodyDynamicFilterSchema.md)
 - [BodyDynamicFilterSchemaFilters](cloudbeds_pms/docs/BodyDynamicFilterSchemaFilters.md)
 - [CursorPaginationSchema](cloudbeds_pms/docs/CursorPaginationSchema.md)
 - [DirectionEnumSchema](cloudbeds_pms/docs/DirectionEnumSchema.md)
 - [DoorLockKeyCreateRequestSchema](cloudbeds_pms/docs/DoorLockKeyCreateRequestSchema.md)
 - [DoorLockKeyFailedToGenerateResponseSchema](cloudbeds_pms/docs/DoorLockKeyFailedToGenerateResponseSchema.md)
 - [DoorLockKeyListRequestSchema](cloudbeds_pms/docs/DoorLockKeyListRequestSchema.md)
 - [DoorLockKeyListResponseSchema](cloudbeds_pms/docs/DoorLockKeyListResponseSchema.md)
 - [DoorLockKeyResponseSchema](cloudbeds_pms/docs/DoorLockKeyResponseSchema.md)
 - [DoorLockKeyUpdateRequestSchema](cloudbeds_pms/docs/DoorLockKeyUpdateRequestSchema.md)
 - [DoorLockSettingsCommonRoomRequestSchema](cloudbeds_pms/docs/DoorLockSettingsCommonRoomRequestSchema.md)
 - [DoorLockSettingsCommonRoomResponseSchema](cloudbeds_pms/docs/DoorLockSettingsCommonRoomResponseSchema.md)
 - [DoorLockSettingsCreateRequestSchema](cloudbeds_pms/docs/DoorLockSettingsCreateRequestSchema.md)
 - [DoorLockSettingsEncoderRequestSchema](cloudbeds_pms/docs/DoorLockSettingsEncoderRequestSchema.md)
 - [DoorLockSettingsEncoderResponseSchema](cloudbeds_pms/docs/DoorLockSettingsEncoderResponseSchema.md)
 - [DoorLockSettingsKeyTypeRequestSchema](cloudbeds_pms/docs/DoorLockSettingsKeyTypeRequestSchema.md)
 - [DoorLockSettingsKeyTypeResponseSchema](cloudbeds_pms/docs/DoorLockSettingsKeyTypeResponseSchema.md)
 - [DoorLockSettingsResponseSchema](cloudbeds_pms/docs/DoorLockSettingsResponseSchema.md)
 - [DynamicFilterFieldSchema](cloudbeds_pms/docs/DynamicFilterFieldSchema.md)
 - [DynamicFilterFieldSchemaValue](cloudbeds_pms/docs/DynamicFilterFieldSchemaValue.md)
 - [DynamicFilterSchema](cloudbeds_pms/docs/DynamicFilterSchema.md)
 - [DynamicFilterSchemaAndInner](cloudbeds_pms/docs/DynamicFilterSchemaAndInner.md)
 - [FeatureEnum](cloudbeds_pms/docs/FeatureEnum.md)
 - [FilterOperatorEnumSchema](cloudbeds_pms/docs/FilterOperatorEnumSchema.md)
 - [ForbiddenResponseSchema](cloudbeds_pms/docs/ForbiddenResponseSchema.md)
 - [GroupCreateRequestSchema](cloudbeds_pms/docs/GroupCreateRequestSchema.md)
 - [GroupDeleteRequestSchema](cloudbeds_pms/docs/GroupDeleteRequestSchema.md)
 - [GroupDisableRequestSchema](cloudbeds_pms/docs/GroupDisableRequestSchema.md)
 - [GroupEnableRequestSchema](cloudbeds_pms/docs/GroupEnableRequestSchema.md)
 - [GroupListResponseSchema](cloudbeds_pms/docs/GroupListResponseSchema.md)
 - [GroupResponseSchema](cloudbeds_pms/docs/GroupResponseSchema.md)
 - [GroupSingleRequestSchema](cloudbeds_pms/docs/GroupSingleRequestSchema.md)
 - [GroupUpdateRequestSchema](cloudbeds_pms/docs/GroupUpdateRequestSchema.md)
 - [ImportFailedToCreateImportTaskSchema](cloudbeds_pms/docs/ImportFailedToCreateImportTaskSchema.md)
 - [ImportFailedToPreProcessResponseSchema](cloudbeds_pms/docs/ImportFailedToPreProcessResponseSchema.md)
 - [ImportFailedToProcessCsvResponseSchema](cloudbeds_pms/docs/ImportFailedToProcessCsvResponseSchema.md)
 - [ImportTaskCreateRequestSchema](cloudbeds_pms/docs/ImportTaskCreateRequestSchema.md)
 - [ImportTaskGetRecordListRequestSchema](cloudbeds_pms/docs/ImportTaskGetRecordListRequestSchema.md)
 - [ImportTaskGetResponseSchema](cloudbeds_pms/docs/ImportTaskGetResponseSchema.md)
 - [ImportTaskListFailedResponseSchema](cloudbeds_pms/docs/ImportTaskListFailedResponseSchema.md)
 - [ImportTaskListRequestSchema](cloudbeds_pms/docs/ImportTaskListRequestSchema.md)
 - [ImportTaskListResponseSchema](cloudbeds_pms/docs/ImportTaskListResponseSchema.md)
 - [ImportTaskRecordGetResponseSchema](cloudbeds_pms/docs/ImportTaskRecordGetResponseSchema.md)
 - [ImportTaskRecordListResponseSchema](cloudbeds_pms/docs/ImportTaskRecordListResponseSchema.md)
 - [ImportTaskResponseSchema](cloudbeds_pms/docs/ImportTaskResponseSchema.md)
 - [InspectionItemSchema](cloudbeds_pms/docs/InspectionItemSchema.md)
 - [InspectionListRequestSchema](cloudbeds_pms/docs/InspectionListRequestSchema.md)
 - [InspectionListResponseSchema](cloudbeds_pms/docs/InspectionListResponseSchema.md)
 - [InternalServerErrorResponseSchema](cloudbeds_pms/docs/InternalServerErrorResponseSchema.md)
 - [LimitOffsetPaginationSchema](cloudbeds_pms/docs/LimitOffsetPaginationSchema.md)
 - [NotFoundResponseSchema](cloudbeds_pms/docs/NotFoundResponseSchema.md)
 - [QueryParameterDynamicFilterSchema](cloudbeds_pms/docs/QueryParameterDynamicFilterSchema.md)
 - [QueryParameterDynamicFilterSchemaFilters](cloudbeds_pms/docs/QueryParameterDynamicFilterSchemaFilters.md)
 - [QueryParameterSortSchema](cloudbeds_pms/docs/QueryParameterSortSchema.md)
 - [SegmentCreateRequestSchema](cloudbeds_pms/docs/SegmentCreateRequestSchema.md)
 - [SegmentDeleteRequestSchema](cloudbeds_pms/docs/SegmentDeleteRequestSchema.md)
 - [SegmentDisableRequestSchema](cloudbeds_pms/docs/SegmentDisableRequestSchema.md)
 - [SegmentEnableRequestSchema](cloudbeds_pms/docs/SegmentEnableRequestSchema.md)
 - [SegmentListRequestSchema](cloudbeds_pms/docs/SegmentListRequestSchema.md)
 - [SegmentListReservationsRequestSchema](cloudbeds_pms/docs/SegmentListReservationsRequestSchema.md)
 - [SegmentListReservationsResponseSchema](cloudbeds_pms/docs/SegmentListReservationsResponseSchema.md)
 - [SegmentListResponseSchema](cloudbeds_pms/docs/SegmentListResponseSchema.md)
 - [SegmentResponseSchema](cloudbeds_pms/docs/SegmentResponseSchema.md)
 - [SegmentSingleRequestSchema](cloudbeds_pms/docs/SegmentSingleRequestSchema.md)
 - [SegmentUpdateRequestSchema](cloudbeds_pms/docs/SegmentUpdateRequestSchema.md)
 - [SortFieldSchema](cloudbeds_pms/docs/SortFieldSchema.md)
 - [SortSchema](cloudbeds_pms/docs/SortSchema.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="api_key"></a>
### api_key

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

<a id="default"></a>
### default

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://api.cloudbeds.com/auth/oauth/authorize
- **Scopes**: 
 - **read:doorLockKey**: Read DoorLock keys and settings
 - **write:doorLockKey**: Write DoorLock keys and settings
 - **read:housekeeping**: Read Housekeeping inspections
 - **read:marketSegmentation**: Read Market Segmentation groups and segments
 - **write:marketSegmentation**: Write Market Segmentation groups and segments
 - **delete:marketSegmentation**: Delete Market Segmentation groups and segments
 - **write:importTask**: Create new data imports
 - **read:importTask**: Read data imports


## Author




